<?php
/**
 * New Zoom Meeting webhook event listener class.
 *
 * @since 2.8.3
 */

namespace Masteriyo\Addons\Zoom\Listener;

use Masteriyo\Abstracts\Listener;
use Masteriyo\Addons\Zoom\Resources\ZoomMeetingResource;
use Masteriyo\Resources\WebhookResource;

defined( 'ABSPATH' ) || exit;

/**
 * New Zoom Meeting webhook event listener class.
 *
 * @since 2.8.3
 */
class NewZoomMeetingListener extends Listener {

	/**
	 * Event name the listener is listening to.
	 *
	 * @since 2.8.3
	 */
	protected $event_name = 'zoom_meeting.created';

	/**
	 * Get event label.
	 *
	 * @since 2.8.3
	 *
	 * @return string
	 */
	public function get_label() {
		return __( 'New Zoom Meeting', 'learning-management-system' );
	}

	/**
	 * Setup the webhook event.
	 *
	 * @since 2.8.3
	 *
	 * @param callable $deliver_callback
	 * @param \Masteriyo\Models\Webhook $webhook
	 */
	public function setup( $deliver_callback, $webhook ) {
		add_action(
			'masteriyo_new_zoom',
			function( $id, $zoom ) use ( $deliver_callback, $webhook ) {
				if ( ! $this->can_deliver( $webhook, $zoom->get_id() ) ) {
					return;
				}

				call_user_func_array(
					$deliver_callback,
					array(
						WebhookResource::to_array( $webhook ),
						$this->get_payload( $zoom, $webhook ),
					)
				);
			},
			10,
			2
		);
	}

	/**
	 * Get payload data for the currently triggered webhook.
	 *
	 * @since 2.8.3
	 *
	 * @param \Masteriyo\Addons\Zoom\Models\Zoom $zoom
	 * @param \Masteriyo\Models\Webhook $webhook
	 *
	 * @return array
	 */
	protected function get_payload( $zoom, $webhook ) {
		$data = ZoomMeetingResource::to_array( $zoom );

		/**
		 * Filters the payload data for the currently triggered webhook.
		 *
		 * @since 2.8.3
		 *
		 * @param array $data The payload data.
		 * @param \Masteriyo\Models\Webhook $webhook
		 */
		return apply_filters( "masteriyo_webhook_payload_for_{$this->event_name}", $data, $webhook );
	}
}
